Bt2020Color class

ITU-R BT.2020 color.

Inheritance

Constructors

Bt2020Color(double r, double g, double b)
const

Properties

b double
Blue channel (0.0–1.0).
finalinherited
clampedB double
Returns clamped b value (0.0–1.0).
no setterinherited
clampedG double
Returns clamped g value (0.0–1.0).
no setterinherited
clampedR double
Returns clamped r value (0.0–1.0).
no setterinherited
g double
Green channel (0.0–1.0).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hex String
Returns the hex string (e.g., '#ff0000').
no setterinherited
r double
Red channel (0.0–1.0).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceDef RgbColorSpaceDef
The RgbColorSpaceDef for this RGB space.
no setteroverride
upscaled → (int, int, int)
Returns upscaled 0–255 integer values.
no setterinherited
values List<double>
Returns the color values as a list.
no setterinherited

Methods

encodeGamma(double v) double
Apply gamma encoding to a linear channel value.
override
linearize(double v) double
BT.2020 transfer function (10-bit system).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited